/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_EQ_HPP_
#define _HEAVY_CONTEXT_WSTD_EQ_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlVar.h"
#include "HvControlUnop.h"
#include "HvMath.h"
#include "HvSignalLine.h"
#include "HvSignalBiquad.h"
#include "HvControlCast.h"
#include "HvControlSystem.h"
#include "HvControlBinop.h"
#include "HvSignalVar.h"
#include "HvControlIf.h"
#include "HvControlSlice.h"

class Heavy_WSTD_EQ : public HeavyContext {

 public:
  Heavy_WSTD_EQ(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_EQ();

  const char *getName() override { return "WSTD_EQ"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_1VUSKlld_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oEKqNexC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_he2YFzvp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xRa6PlSt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Szlj4jPU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_lYe1d4e1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vrO2Tzyv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_UEn70r9k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GgWykoIc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_StZgrh1c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_PZxGWwBQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0amoZUz7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_20TSnc5w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j7K0UB4r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o9Si5O2S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yShEItz8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BAsDy2An_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g8ZHCCOE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FtsxlPtx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5QHOCdRu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_bLKO5pCY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tbJHvpWX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_80mdMmcN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yQrLI3wZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qbC3jQkQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xD08bjeV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PcOJcRO3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qooOlxVD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iMU0fbFB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sjpUM3V5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_d3eFNzCG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_peiNUwJw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_7h5Ez9Zc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_1URkCSDm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nhLxCgpq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_glCTGpc3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Lzds9ulQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_m4Tjz9Lg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_R4PtCLNh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f1agnqky_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JYBTs37w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mSas6CBW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dz1YnVkx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_mqIKI0QJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_diHv8cp3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pvRHJen7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Fy8ZQuBs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ECw4NIWb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6hPnfII1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0aOGmdqi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_h5BulwXt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qAtUiFSW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Fu8dj7tN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_goh3u3ug_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_H9nCzFB5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_POuYB8Qg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_8wW2jovO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nwWbfCDR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g8z3FevR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_szl5DAjH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dFI6L2I7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wIG2ps8W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OaGXjILt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JiUGYqgp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OkxT0iF5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KUv3mtSk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_AZXABIWk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uBD4GQnU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tTvP54r5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UMuLHNTp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tpRjZaEC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b89LsMPr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XaPacNIw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jASc43g5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sVM4Ki5z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vhGVcoMr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bdi7WnCN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CpzTtGIG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_HJ1fLuEZ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_gvNIRIv6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MfUl7Qll_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_MdAumJt5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GvTawKX7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Fo96H8Yp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GYHDdMtk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_vpaLHiIH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hSUh0bUn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_jElulFlh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0dKnhW9y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_VdpWB8RH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1R19vqJ7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_sJTOUuDp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6q9dJT88_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_rvt702dx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_83KLSFmj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tPX2mtZ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wuZrg55D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aX5IuQYm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yAU81QU3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cTlgz51N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_B9FJDEUf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_sVuwbFnl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WGtJHFY1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u88MyiRA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CqLRrWG6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NGxRG1gn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wy6iGeNh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_LJeNzuJT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_NjeHFPYt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uOZntB6h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3xVD9B8T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EstoPiUt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JT7Ns62f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qodGIkQ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wII1QFwK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PiEHNWji_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AVs5iu0w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bJzdaYVk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WytLsADh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_069Yrj2C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3YrTCjYp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ISjdXJDV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XBpKy44d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n8kbIup6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VjdWjhmX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HCTvKMO0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9G8Klvf7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hlmfMIK0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Jl8dx8CD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_z20kMTjb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_vs7y8Mlj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QtlNl3lR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5ORgYCFe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qXIrobaf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2WelfzEY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V9pk4E6Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YoEjGaoK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yLYUBNcd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KKgN74Ce_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1JUK97cM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1iPKdU4Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Iv989HUL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tFLrLqe4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wO8fp7FY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2gIKBmhV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dnDC1LAJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0xtjj0zh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fdvODSko_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_upwg7HEY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TuNTuPsE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_r0ejlWSJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_snWo0s07_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_crGN1c8c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rzPrlzj3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dHyx4Nvh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_39EMJBsd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MRNtKtYr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_rrJ6RlRG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_AILYnYDT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ht5zTN9l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TzYkresa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gFqb6Br8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WefrlnoH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_D7dTuXiz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_MhTc0ZOO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_GlkPkoC1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ty9Y2oJX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FlX90UVp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TZTL71Di_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vlJh0pe6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1LSazRc3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tC1gT2uH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4jtuOfKa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_u77ZdL1O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MeqsTeH0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_S4TPiMmV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fdRjYPc3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KMr2c1JS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FMsrVorE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ej6nYk82_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_eJXADy7q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_bjgxP3Ny_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_EtQqzU7k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bqY0GiOk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F3stp9c3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QNLcoVnP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SsI4pf4q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o3mCLZ8S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZkEIQ0UG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_84FnrTph_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OeQHLct9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Sg3RgKYT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oGR7EQsT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_59jhKYFa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1l8srMHD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eBDzPZL7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_T2X9wTZt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ytj3jEJe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DOb19L87_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hdaAoxAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6vWvqstr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zJrcFzRl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hHWs8Byn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sFLpTt5L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bqcvvzS8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Dqw9R0kp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hiHkKwFK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Z5Ub4iI6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_vwnIR9Hx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q59K7TD3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fgd0pSDp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7qiigzyT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a29Wh1vc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CAPgf3BQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_u3b8EOVZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_pKpga3lb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C8ysqepD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9ujvh1gJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hsvOpHnr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VEBNpaAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VqATldA6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sAjd6vjN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6RBoNdWw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8yMCrfbT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3CvMjGFt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dl7fDLor_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W7LJKBBR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rsNA1XPG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SW8oh5Ti_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n0Xv6n1M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A9vnxjiQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EEQntRUw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_65QsiDbn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tzQ9uwCR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_M1LwUZBm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q4gppIhT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mvdLyvZ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_iVIO4OWj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_y1hcT3Ne_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_d8AEJKTY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kVEgRKh7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8jMuCKxt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sq9cXgNz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ya3Q2XL2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pRWhNIPV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kVrht0w0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZBIuIgDz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5GJc0qpD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AuRMijMd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7o7GE8IU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3EkL3c8Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OLfFVuI1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ctaRPBKX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0WXl0qmC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KmGvOHZ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_74Zjllqr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xpPfuXWY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CacHgGhI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NyiEUH1E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_josPDXg6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bbbhlF1C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qC50caMz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NiJzfIC3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_efxz3pb2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DojUuHWb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_c4ZrQBXa_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_OTCFyzze_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0ZB4d1FS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_qlE7pcPd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KYHLDl6Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_sArZq3z3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_pchDWC0n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yqb2hzkc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MxtWx4iX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sFeW4mPL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JlcL2hXF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_32CD65ZR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xo2ivqpJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q2HdK7xW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_grMTm2T3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_evynoLNx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5k4rX5kZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zCEb89Ms_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VL4cX8Ch_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TopAltZG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NFs7ZE7m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7X8Qp76H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PCo8nGDd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nMzXDwVo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ab3RtfLn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z4ZXUuZ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_F0W1a6HN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jwgm1GY8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9pPRJh8F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_OOh7vfXP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s1sI4hST_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4p1iFxgk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3QCiOEvw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FWUufxqM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_csENvkki_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nDZMxG8o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OtPovGQb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Rk1fGZys_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V5wfxTfw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WJQnBdqf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CXni3fk0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6C0j2mQO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8uvRPBGM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k8S57yox_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S5acli40_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H4TXB2Go_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0HEZ86i4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IkJOOxIc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zGPCzoIn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eRvtyZ0R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OsHshlk3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ECVFvbtQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lQRs23PQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZhYlifBC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QwxcfBo3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MOLSaVuI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0OEC7f2J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qeAifqPd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kDtJgC2w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DvkcJMNT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PlfIMdrt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XvEYczBO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_36sNSBSu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cutgKjQh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_usxiwDMf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Xl4YRpYu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rQOcc2rm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sH5C9cxr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v2lVd3eS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wdnSwYv0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JL3kXSCn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LFJzqJx8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aiLvbjxL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_xC9e56LR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Gjwf1HWa_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_6nANz90T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zyAv9GYB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_M0dLdLxf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_RkV4avAK_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_DnhdJA40_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_z8tRXTtq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_gcNB26o0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_PhXSgPXq_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_b4xqlSgE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jpZMdPrq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_n3X8VaMZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MmGtgXBJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_I7TvgrqP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aAjwDCXP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_pZm9KXx7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p8fn6Jg4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GVdfOCiV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TthioetN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_52UGStkC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uv2mbXfj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zuGRraS3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_QLogKkFF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_G79cySih_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2ehpCojp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eJwYQ3Wl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ReClTFjc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ja2zTTZy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LaweWJF4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_HDBKiY2q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_tEp3WmPO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SymJzGcr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6Epk2tzH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lfAgfmlF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uO0kC3ea_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BUQscI0g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_n804V9HW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H6Necpo7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NyRekMvf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_txgcf6N7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T8BfGqXh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_owJmt3eT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qwEnHDUL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BTNQWwHd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vPYVQWt8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0YUrub6P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rh91WO4S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gu8IuqPF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KuTqhWuN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OcuzvDbw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_n90ekfJP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hlKxbH4b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hYGRfQrp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7r4v6JWe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RzgeEJr3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PAPlKye4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1w6Dkiqk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Amt1midJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cMsuuH6Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c4MTDz9g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KXUxMZXZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j3oAlhbU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wfrQflPR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pjCnWrxZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cbFsgCmt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rU69UVlq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ifwUBCKM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N3ScA7YB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uQTkFm2r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t4QycUdF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jNc61ule_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_97XWIguG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1TrHnZ76_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IBcXc91h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X6FIX6Vh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hTUMXUpE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U52DvwZR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LgX0mjdn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2Gq3gzAb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FqM9vpxl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_QD4GIjNe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FvwdWonF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d2WuTyvI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LTUETP30_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NLwL4bq5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fCRTwPVp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_EyHxItxb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_lQgihfjJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_85fFZUSi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GOBf8Dqt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bFVywWxV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lsDaAhKS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rU42iKgt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R7HQFYcr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W0xJytXF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6pe1ZrwU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_45vgPV4V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hwNcd1Py_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_K7TskBoY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XglvraEc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_v1FFkMxb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c29eDhqN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_NjR9m7sm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_iU3kdwcg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_dS0e0ssH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2H8ivPf7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d0FUfCdF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LVJzLVhr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F1VHmkVM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OH8Z55I5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zLPaQOVQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bWrFTUfH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_npB8VbUi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GSnG9B3i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I9jln8c6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_konAOXgp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ukh7JRaZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZoDF6evV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZNQ9cxT6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yGQVXvEG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_puulP1mC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6eJ0HNdc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8jsRi1aS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zTo3ZfoZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Npgub575_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hhwUUukD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vk9gYr1E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KT7ty421_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7VTzl2AN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_5c07it0K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_XZWAIqiW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ye531ShB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ggh7JLUW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BQfFyweO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DGwjxIxf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QyZFyKSz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_kbAq6D3Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_SZNy3gwj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GdN2MhgC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IpQ78yoy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3JQDnHZe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TrhbUsTE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nQevZGvA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3BUMqkiI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UWCIyDKy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o1kq28pK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tealPr4o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TZwJAoUV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kjYVGW93_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UsxrsQF6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_04uYbpe5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3QWsvEy9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X3Dyt8X7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F8vsXCwW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AJ6lkvyY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Zwf5bN8t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0xn1eWj3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pFLsWNGX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YUTWGfTo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ihyShnqs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_d2rNIs9J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_eMihhNjd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0Wnb41wp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pg5SRJMC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OIvVBUs7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BLFQJWPA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rm1yhyB7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iRoxLHTX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uIDoQi0n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Cq6mkKGU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FtelRgR6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xEYOt3et_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1Uc1FFHy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qACQsg2m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WcJZBgot_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AHzeMKbJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nWzgt0et_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CRti13t7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Fh6vn4qz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eJNmiT5R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jPsF7m7V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Mu7kE48k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MtVP3CMa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lrZJdMlf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tGZijSes_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1eAzubUA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6E2htVTg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_23r5D3D6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_thaJpZ9A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_qciztkVt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ST6rPDuI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4MOjHjQh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a7C8LwRV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o3jwWUhc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LUJ22E11_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RDvrZnyd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g4hQNDck_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_SkYEw6Vv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vDfDHErc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QMKB4n22_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oyrsSds1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gF0Ii98h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KxuitFKM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GnN0KIsl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xyr7VFkr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jWPdz7dC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rxJuEbvy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wQ86Xtz6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dUuYEFCU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nROUAtnE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JWWltq2i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Baj6m5D3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bwWe1eKc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_L9ie4pW0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rJnSh8ty_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5pxaqpCJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Pk3J3FWr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GKCcu1id_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LxNaQQ2y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1uukJvLb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YMLR4bWg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rkNdC3v4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JN0Axs3W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Aak0DAR3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XmCd1KcI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_v3TC0d3S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_em2JHF1x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PWdt1QPl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qRvpNtna_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pVi1GzjM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TVOfHe3B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RUnorDEv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bLD4uKY7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nNv9uUlk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_NDMxZ6Sp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rY1f2ZNF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rRXg3prH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Utg5zv0R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iLmjMNt4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qd7A8AIa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nZKyueI5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_P1nWethQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_oIDNwRB4;
  SignalLine sLine_g2eww61p;
  SignalLine sLine_yxaBnASD;
  SignalLine sLine_sv7djy5m;
  SignalLine sLine_OsEGMFGH;
  SignalBiquad sBiquad_s_Zlq4yOXg;
  SignalLine sLine_hPlV1gZO;
  SignalLine sLine_lAjyaGno;
  SignalLine sLine_7ySbxA0C;
  SignalLine sLine_nMKTl4O3;
  SignalBiquad sBiquad_s_OZiUGMFV;
  SignalLine sLine_7VKn1ntj;
  SignalLine sLine_FKtLizkA;
  SignalLine sLine_yJrVmjc1;
  SignalLine sLine_tPZM1fPE;
  SignalLine sLine_aPiqalVm;
  SignalBiquad sBiquad_s_iP9iAEsT;
  SignalLine sLine_pglqpfwH;
  SignalLine sLine_Jff4iP70;
  SignalLine sLine_rCIlL3GO;
  SignalLine sLine_Bp2NubGC;
  SignalLine sLine_9ffIT4ej;
  SignalBiquad sBiquad_s_obQxFgqf;
  SignalLine sLine_OHWkXJ1m;
  SignalLine sLine_XaA7LH24;
  SignalLine sLine_m5hq0WPa;
  SignalLine sLine_gkennT1q;
  SignalBiquad sBiquad_s_sQ5GpE8k;
  SignalLine sLine_RRgM89lg;
  SignalLine sLine_INgH8amA;
  SignalLine sLine_N9bitpNe;
  SignalLine sLine_pe4QlAzU;
  SignalLine sLine_n511gYbr;
  SignalBiquad sBiquad_s_4nWWtFCp;
  ControlVar cVar_1VUSKlld;
  ControlVar cVar_oEKqNexC;
  ControlVar cVar_he2YFzvp;
  ControlVar cVar_xRa6PlSt;
  ControlSlice cSlice_lYe1d4e1;
  ControlVar cVar_vrO2Tzyv;
  ControlVar cVar_GgWykoIc;
  ControlIf cIf_StZgrh1c;
  ControlIf cIf_PZxGWwBQ;
  ControlBinop cBinop_20TSnc5w;
  ControlBinop cBinop_j7K0UB4r;
  ControlBinop cBinop_BAsDy2An;
  ControlBinop cBinop_g8ZHCCOE;
  ControlBinop cBinop_5QHOCdRu;
  ControlIf cIf_bLKO5pCY;
  ControlBinop cBinop_tbJHvpWX;
  ControlBinop cBinop_80mdMmcN;
  ControlBinop cBinop_qbC3jQkQ;
  ControlBinop cBinop_xD08bjeV;
  ControlBinop cBinop_PcOJcRO3;
  ControlVar cVar_peiNUwJw;
  ControlIf cIf_7h5Ez9Zc;
  ControlIf cIf_1URkCSDm;
  ControlBinop cBinop_glCTGpc3;
  ControlBinop cBinop_Lzds9ulQ;
  ControlBinop cBinop_f1agnqky;
  ControlBinop cBinop_JYBTs37w;
  ControlBinop cBinop_dz1YnVkx;
  ControlIf cIf_mqIKI0QJ;
  ControlBinop cBinop_diHv8cp3;
  ControlBinop cBinop_pvRHJen7;
  ControlBinop cBinop_ECw4NIWb;
  ControlBinop cBinop_6hPnfII1;
  ControlBinop cBinop_0aOGmdqi;
  ControlVar cVar_H9nCzFB5;
  ControlIf cIf_POuYB8Qg;
  ControlIf cIf_8wW2jovO;
  ControlBinop cBinop_g8z3FevR;
  ControlBinop cBinop_szl5DAjH;
  ControlBinop cBinop_OaGXjILt;
  ControlBinop cBinop_JiUGYqgp;
  ControlBinop cBinop_KUv3mtSk;
  ControlIf cIf_AZXABIWk;
  ControlBinop cBinop_uBD4GQnU;
  ControlBinop cBinop_tTvP54r5;
  ControlBinop cBinop_tpRjZaEC;
  ControlBinop cBinop_b89LsMPr;
  ControlBinop cBinop_XaPacNIw;
  ControlIf cIf_CpzTtGIG;
  ControlSlice cSlice_gvNIRIv6;
  ControlVar cVar_MfUl7Qll;
  ControlSlice cSlice_Fo96H8Yp;
  ControlVar cVar_GYHDdMtk;
  ControlSlice cSlice_jElulFlh;
  ControlVar cVar_0dKnhW9y;
  ControlSlice cSlice_sJTOUuDp;
  ControlVar cVar_6q9dJT88;
  ControlBinop cBinop_u88MyiRA;
  ControlBinop cBinop_NGxRG1gn;
  ControlBinop cBinop_wy6iGeNh;
  ControlBinop cBinop_uOZntB6h;
  ControlBinop cBinop_3xVD9B8T;
  ControlBinop cBinop_EstoPiUt;
  ControlBinop cBinop_JT7Ns62f;
  ControlBinop cBinop_qodGIkQ5;
  ControlVar cVar_wII1QFwK;
  ControlBinop cBinop_PiEHNWji;
  ControlBinop cBinop_AVs5iu0w;
  ControlBinop cBinop_bJzdaYVk;
  ControlBinop cBinop_WytLsADh;
  ControlBinop cBinop_069Yrj2C;
  ControlBinop cBinop_3YrTCjYp;
  ControlBinop cBinop_ISjdXJDV;
  ControlBinop cBinop_n8kbIup6;
  ControlVar cVar_VjdWjhmX;
  ControlVar cVar_HCTvKMO0;
  ControlBinop cBinop_5ORgYCFe;
  ControlBinop cBinop_qXIrobaf;
  ControlBinop cBinop_2WelfzEY;
  ControlBinop cBinop_YoEjGaoK;
  ControlBinop cBinop_yLYUBNcd;
  ControlBinop cBinop_KKgN74Ce;
  ControlBinop cBinop_1JUK97cM;
  ControlBinop cBinop_1iPKdU4Y;
  ControlBinop cBinop_Iv989HUL;
  ControlBinop cBinop_TzYkresa;
  ControlBinop cBinop_WefrlnoH;
  ControlBinop cBinop_D7dTuXiz;
  ControlBinop cBinop_Ty9Y2oJX;
  ControlBinop cBinop_FlX90UVp;
  ControlBinop cBinop_TZTL71Di;
  ControlBinop cBinop_vlJh0pe6;
  ControlBinop cBinop_1LSazRc3;
  ControlBinop cBinop_tC1gT2uH;
  ControlBinop cBinop_4jtuOfKa;
  ControlBinop cBinop_MeqsTeH0;
  ControlVar cVar_S4TPiMmV;
  ControlVar cVar_fdRjYPc3;
  ControlVar cVar_KMr2c1JS;
  ControlBinop cBinop_F3stp9c3;
  ControlBinop cBinop_QNLcoVnP;
  ControlBinop cBinop_SsI4pf4q;
  ControlBinop cBinop_ZkEIQ0UG;
  ControlBinop cBinop_84FnrTph;
  ControlBinop cBinop_OeQHLct9;
  ControlBinop cBinop_Sg3RgKYT;
  ControlBinop cBinop_oGR7EQsT;
  ControlBinop cBinop_fgd0pSDp;
  ControlBinop cBinop_a29Wh1vc;
  ControlBinop cBinop_CAPgf3BQ;
  ControlBinop cBinop_C8ysqepD;
  ControlBinop cBinop_9ujvh1gJ;
  ControlBinop cBinop_hsvOpHnr;
  ControlBinop cBinop_VEBNpaAS;
  ControlBinop cBinop_VqATldA6;
  ControlBinop cBinop_6RBoNdWw;
  ControlBinop cBinop_3CvMjGFt;
  ControlBinop cBinop_dl7fDLor;
  ControlBinop cBinop_rsNA1XPG;
  ControlBinop cBinop_SW8oh5Ti;
  ControlBinop cBinop_n0Xv6n1M;
  ControlBinop cBinop_EEQntRUw;
  ControlVar cVar_65QsiDbn;
  ControlVar cVar_tzQ9uwCR;
  ControlVar cVar_M1LwUZBm;
  ControlBinop cBinop_8jMuCKxt;
  ControlBinop cBinop_sq9cXgNz;
  ControlBinop cBinop_Ya3Q2XL2;
  ControlBinop cBinop_kVrht0w0;
  ControlBinop cBinop_ZBIuIgDz;
  ControlBinop cBinop_5GJc0qpD;
  ControlBinop cBinop_AuRMijMd;
  ControlBinop cBinop_7o7GE8IU;
  ControlBinop cBinop_3EkL3c8Q;
  ControlBinop cBinop_qC50caMz;
  ControlBinop cBinop_efxz3pb2;
  ControlBinop cBinop_DojUuHWb;
  SignalVarf sVarf_h1dMVlpZ;
  SignalVarf sVarf_24qFCSEa;
  SignalVarf sVarf_7ICFxOGA;
  ControlSlice cSlice_OTCFyzze;
  ControlVar cVar_0ZB4d1FS;
  ControlVar cVar_KYHLDl6Q;
  ControlIf cIf_sArZq3z3;
  ControlIf cIf_pchDWC0n;
  ControlBinop cBinop_MxtWx4iX;
  ControlBinop cBinop_sFeW4mPL;
  ControlBinop cBinop_xo2ivqpJ;
  ControlBinop cBinop_Q2HdK7xW;
  ControlBinop cBinop_evynoLNx;
  ControlIf cIf_5k4rX5kZ;
  ControlBinop cBinop_zCEb89Ms;
  ControlBinop cBinop_VL4cX8Ch;
  ControlBinop cBinop_NFs7ZE7m;
  ControlBinop cBinop_7X8Qp76H;
  ControlBinop cBinop_PCo8nGDd;
  ControlVar cVar_jwgm1GY8;
  ControlIf cIf_9pPRJh8F;
  ControlIf cIf_OOh7vfXP;
  ControlBinop cBinop_4p1iFxgk;
  ControlBinop cBinop_3QCiOEvw;
  ControlBinop cBinop_nDZMxG8o;
  ControlBinop cBinop_OtPovGQb;
  ControlBinop cBinop_V5wfxTfw;
  ControlIf cIf_WJQnBdqf;
  ControlBinop cBinop_CXni3fk0;
  ControlBinop cBinop_6C0j2mQO;
  ControlBinop cBinop_k8S57yox;
  ControlBinop cBinop_S5acli40;
  ControlBinop cBinop_H4TXB2Go;
  ControlVar cVar_OsHshlk3;
  ControlIf cIf_ECVFvbtQ;
  ControlIf cIf_lQRs23PQ;
  ControlBinop cBinop_QwxcfBo3;
  ControlBinop cBinop_MOLSaVuI;
  ControlBinop cBinop_kDtJgC2w;
  ControlBinop cBinop_DvkcJMNT;
  ControlBinop cBinop_XvEYczBO;
  ControlIf cIf_36sNSBSu;
  ControlBinop cBinop_cutgKjQh;
  ControlBinop cBinop_usxiwDMf;
  ControlBinop cBinop_rQOcc2rm;
  ControlBinop cBinop_sH5C9cxr;
  ControlBinop cBinop_v2lVd3eS;
  ControlIf cIf_xC9e56LR;
  ControlSlice cSlice_6nANz90T;
  ControlVar cVar_zyAv9GYB;
  ControlSlice cSlice_DnhdJA40;
  ControlVar cVar_z8tRXTtq;
  ControlSlice cSlice_b4xqlSgE;
  ControlVar cVar_jpZMdPrq;
  ControlSlice cSlice_I7TvgrqP;
  ControlVar cVar_aAjwDCXP;
  ControlBinop cBinop_eJwYQ3Wl;
  ControlBinop cBinop_Ja2zTTZy;
  ControlBinop cBinop_LaweWJF4;
  ControlBinop cBinop_SymJzGcr;
  ControlBinop cBinop_6Epk2tzH;
  ControlBinop cBinop_lfAgfmlF;
  ControlBinop cBinop_uO0kC3ea;
  ControlBinop cBinop_BUQscI0g;
  ControlVar cVar_n804V9HW;
  ControlBinop cBinop_H6Necpo7;
  ControlBinop cBinop_NyRekMvf;
  ControlBinop cBinop_txgcf6N7;
  ControlBinop cBinop_T8BfGqXh;
  ControlBinop cBinop_owJmt3eT;
  ControlBinop cBinop_qwEnHDUL;
  ControlBinop cBinop_BTNQWwHd;
  ControlBinop cBinop_0YUrub6P;
  ControlVar cVar_rh91WO4S;
  ControlVar cVar_gu8IuqPF;
  ControlBinop cBinop_RzgeEJr3;
  ControlBinop cBinop_PAPlKye4;
  ControlBinop cBinop_1w6Dkiqk;
  ControlBinop cBinop_cMsuuH6Z;
  ControlBinop cBinop_c4MTDz9g;
  ControlBinop cBinop_KXUxMZXZ;
  ControlBinop cBinop_j3oAlhbU;
  ControlBinop cBinop_wfrQflPR;
  ControlBinop cBinop_pjCnWrxZ;
  ControlBinop cBinop_d2WuTyvI;
  ControlBinop cBinop_NLwL4bq5;
  ControlBinop cBinop_fCRTwPVp;
  ControlBinop cBinop_85fFZUSi;
  ControlBinop cBinop_GOBf8Dqt;
  ControlBinop cBinop_bFVywWxV;
  ControlBinop cBinop_lsDaAhKS;
  ControlBinop cBinop_rU42iKgt;
  ControlBinop cBinop_R7HQFYcr;
  ControlBinop cBinop_W0xJytXF;
  ControlBinop cBinop_45vgPV4V;
  ControlVar cVar_hwNcd1Py;
  ControlVar cVar_K7TskBoY;
  ControlVar cVar_XglvraEc;
  ControlBinop cBinop_d0FUfCdF;
  ControlBinop cBinop_LVJzLVhr;
  ControlBinop cBinop_F1VHmkVM;
  ControlBinop cBinop_zLPaQOVQ;
  ControlBinop cBinop_bWrFTUfH;
  ControlBinop cBinop_npB8VbUi;
  ControlBinop cBinop_GSnG9B3i;
  ControlBinop cBinop_I9jln8c6;
  ControlBinop cBinop_Ggh7JLUW;
  ControlBinop cBinop_DGwjxIxf;
  ControlBinop cBinop_QyZFyKSz;
  ControlBinop cBinop_GdN2MhgC;
  ControlBinop cBinop_IpQ78yoy;
  ControlBinop cBinop_3JQDnHZe;
  ControlBinop cBinop_TrhbUsTE;
  ControlBinop cBinop_nQevZGvA;
  ControlBinop cBinop_UWCIyDKy;
  ControlBinop cBinop_tealPr4o;
  ControlBinop cBinop_TZwJAoUV;
  ControlBinop cBinop_UsxrsQF6;
  ControlBinop cBinop_04uYbpe5;
  ControlBinop cBinop_3QWsvEy9;
  ControlBinop cBinop_F8vsXCwW;
  ControlVar cVar_AJ6lkvyY;
  ControlVar cVar_Zwf5bN8t;
  ControlVar cVar_0xn1eWj3;
  ControlBinop cBinop_pg5SRJMC;
  ControlBinop cBinop_OIvVBUs7;
  ControlBinop cBinop_BLFQJWPA;
  ControlBinop cBinop_iRoxLHTX;
  ControlBinop cBinop_uIDoQi0n;
  ControlBinop cBinop_Cq6mkKGU;
  ControlBinop cBinop_FtelRgR6;
  ControlBinop cBinop_xEYOt3et;
  ControlBinop cBinop_1Uc1FFHy;
  ControlBinop cBinop_lrZJdMlf;
  ControlBinop cBinop_1eAzubUA;
  ControlBinop cBinop_6E2htVTg;
  SignalVarf sVarf_VLcMTiW7;
  SignalVarf sVarf_CNRXIg57;
  SignalVarf sVarf_jDtDyJsp;
  SignalVarf sVarf_cgQt33QM;
  SignalVarf sVarf_m8Dpuu7I;
  SignalVarf sVarf_BBgKLty9;
  SignalVarf sVarf_oY1ADyOm;
  SignalVarf sVarf_Oh3AXYxM;
  SignalVarf sVarf_xzxEVkmt;
  ControlVar cVar_23r5D3D6;
  ControlVar cVar_thaJpZ9A;
  ControlBinop cBinop_LUJ22E11;
  ControlBinop cBinop_RDvrZnyd;
  ControlBinop cBinop_g4hQNDck;
  ControlBinop cBinop_vDfDHErc;
  ControlBinop cBinop_QMKB4n22;
  ControlBinop cBinop_oyrsSds1;
  ControlBinop cBinop_gF0Ii98h;
};

#endif // _HEAVY_CONTEXT_WSTD_EQ_HPP_
