/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_EQ.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_EQ *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_EQ_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_EQ();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_EQ::Heavy_WSTD_EQ(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_oIDNwRB4);
  numBytes += sLine_init(&sLine_g2eww61p);
  numBytes += sLine_init(&sLine_yxaBnASD);
  numBytes += sLine_init(&sLine_sv7djy5m);
  numBytes += sLine_init(&sLine_OsEGMFGH);
  numBytes += sBiquad_init(&sBiquad_s_Zlq4yOXg);
  numBytes += sLine_init(&sLine_hPlV1gZO);
  numBytes += sLine_init(&sLine_lAjyaGno);
  numBytes += sLine_init(&sLine_7ySbxA0C);
  numBytes += sLine_init(&sLine_nMKTl4O3);
  numBytes += sBiquad_init(&sBiquad_s_OZiUGMFV);
  numBytes += sLine_init(&sLine_7VKn1ntj);
  numBytes += sLine_init(&sLine_FKtLizkA);
  numBytes += sLine_init(&sLine_yJrVmjc1);
  numBytes += sLine_init(&sLine_tPZM1fPE);
  numBytes += sLine_init(&sLine_aPiqalVm);
  numBytes += sBiquad_init(&sBiquad_s_iP9iAEsT);
  numBytes += sLine_init(&sLine_pglqpfwH);
  numBytes += sLine_init(&sLine_Jff4iP70);
  numBytes += sLine_init(&sLine_rCIlL3GO);
  numBytes += sLine_init(&sLine_Bp2NubGC);
  numBytes += sLine_init(&sLine_9ffIT4ej);
  numBytes += sBiquad_init(&sBiquad_s_obQxFgqf);
  numBytes += sLine_init(&sLine_OHWkXJ1m);
  numBytes += sLine_init(&sLine_XaA7LH24);
  numBytes += sLine_init(&sLine_m5hq0WPa);
  numBytes += sLine_init(&sLine_gkennT1q);
  numBytes += sBiquad_init(&sBiquad_s_sQ5GpE8k);
  numBytes += sLine_init(&sLine_RRgM89lg);
  numBytes += sLine_init(&sLine_INgH8amA);
  numBytes += sLine_init(&sLine_N9bitpNe);
  numBytes += sLine_init(&sLine_pe4QlAzU);
  numBytes += sLine_init(&sLine_n511gYbr);
  numBytes += sBiquad_init(&sBiquad_s_4nWWtFCp);
  numBytes += cVar_init_f(&cVar_1VUSKlld, 0.0f);
  numBytes += cVar_init_f(&cVar_oEKqNexC, 0.0f);
  numBytes += cVar_init_f(&cVar_he2YFzvp, 0.0f);
  numBytes += cVar_init_f(&cVar_xRa6PlSt, 0.0f);
  numBytes += cSlice_init(&cSlice_lYe1d4e1, 1, -1);
  numBytes += cVar_init_f(&cVar_vrO2Tzyv, 1337.0f);
  numBytes += cVar_init_f(&cVar_GgWykoIc, 0.0f);
  numBytes += cIf_init(&cIf_StZgrh1c, false);
  numBytes += cIf_init(&cIf_PZxGWwBQ, false);
  numBytes += cBinop_init(&cBinop_20TSnc5w, 0.0f); // __pow
  numBytes += cIf_init(&cIf_bLKO5pCY, false);
  numBytes += cBinop_init(&cBinop_qbC3jQkQ, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_xD08bjeV, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_PcOJcRO3, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_peiNUwJw, 0.0f);
  numBytes += cIf_init(&cIf_7h5Ez9Zc, false);
  numBytes += cIf_init(&cIf_1URkCSDm, false);
  numBytes += cBinop_init(&cBinop_glCTGpc3, 0.0f); // __pow
  numBytes += cIf_init(&cIf_mqIKI0QJ, false);
  numBytes += cBinop_init(&cBinop_ECw4NIWb, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_6hPnfII1, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_0aOGmdqi, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_H9nCzFB5, 0.0f);
  numBytes += cIf_init(&cIf_POuYB8Qg, false);
  numBytes += cIf_init(&cIf_8wW2jovO, false);
  numBytes += cBinop_init(&cBinop_g8z3FevR, 0.0f); // __pow
  numBytes += cIf_init(&cIf_AZXABIWk, false);
  numBytes += cBinop_init(&cBinop_tpRjZaEC, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_b89LsMPr, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_XaPacNIw, -15.0f); // __eq
  numBytes += cIf_init(&cIf_CpzTtGIG, false);
  numBytes += cSlice_init(&cSlice_gvNIRIv6, 1, -1);
  numBytes += cVar_init_f(&cVar_MfUl7Qll, 0.0f);
  numBytes += cSlice_init(&cSlice_Fo96H8Yp, 1, -1);
  numBytes += cVar_init_f(&cVar_GYHDdMtk, 0.0f);
  numBytes += cSlice_init(&cSlice_jElulFlh, 1, -1);
  numBytes += cVar_init_f(&cVar_0dKnhW9y, 0.0f);
  numBytes += cSlice_init(&cSlice_sJTOUuDp, 1, -1);
  numBytes += cVar_init_f(&cVar_6q9dJT88, 0.313f);
  numBytes += cBinop_init(&cBinop_NGxRG1gn, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_wy6iGeNh, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_wII1QFwK, 0.0f);
  numBytes += cVar_init_f(&cVar_VjdWjhmX, 1337.0f);
  numBytes += cVar_init_f(&cVar_HCTvKMO0, 0.3f);
  numBytes += cBinop_init(&cBinop_qXIrobaf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yLYUBNcd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KKgN74Ce, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1JUK97cM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1iPKdU4Y, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Iv989HUL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WefrlnoH, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_D7dTuXiz, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_S4TPiMmV, 0.0f);
  numBytes += cVar_init_f(&cVar_fdRjYPc3, 1337.0f);
  numBytes += cVar_init_f(&cVar_KMr2c1JS, 0.313f);
  numBytes += cBinop_init(&cBinop_QNLcoVnP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_84FnrTph, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OeQHLct9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Sg3RgKYT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oGR7EQsT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_a29Wh1vc, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_CAPgf3BQ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_65QsiDbn, 0.0f);
  numBytes += cVar_init_f(&cVar_tzQ9uwCR, 1037.0f);
  numBytes += cVar_init_f(&cVar_M1LwUZBm, 0.4f);
  numBytes += cBinop_init(&cBinop_sq9cXgNz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZBIuIgDz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5GJc0qpD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AuRMijMd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7o7GE8IU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3EkL3c8Q, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_h1dMVlpZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_24qFCSEa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7ICFxOGA, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_OTCFyzze, 1, -1);
  numBytes += cVar_init_f(&cVar_0ZB4d1FS, 1337.0f);
  numBytes += cVar_init_f(&cVar_KYHLDl6Q, 0.0f);
  numBytes += cIf_init(&cIf_sArZq3z3, false);
  numBytes += cIf_init(&cIf_pchDWC0n, false);
  numBytes += cBinop_init(&cBinop_MxtWx4iX, 0.0f); // __pow
  numBytes += cIf_init(&cIf_5k4rX5kZ, false);
  numBytes += cBinop_init(&cBinop_NFs7ZE7m, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_7X8Qp76H, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_PCo8nGDd, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_jwgm1GY8, 0.0f);
  numBytes += cIf_init(&cIf_9pPRJh8F, false);
  numBytes += cIf_init(&cIf_OOh7vfXP, false);
  numBytes += cBinop_init(&cBinop_4p1iFxgk, 0.0f); // __pow
  numBytes += cIf_init(&cIf_WJQnBdqf, false);
  numBytes += cBinop_init(&cBinop_k8S57yox, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_S5acli40, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_H4TXB2Go, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_OsHshlk3, 0.0f);
  numBytes += cIf_init(&cIf_ECVFvbtQ, false);
  numBytes += cIf_init(&cIf_lQRs23PQ, false);
  numBytes += cBinop_init(&cBinop_QwxcfBo3, 0.0f); // __pow
  numBytes += cIf_init(&cIf_36sNSBSu, false);
  numBytes += cBinop_init(&cBinop_rQOcc2rm, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_sH5C9cxr, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_v2lVd3eS, -15.0f); // __eq
  numBytes += cIf_init(&cIf_xC9e56LR, false);
  numBytes += cSlice_init(&cSlice_6nANz90T, 1, -1);
  numBytes += cVar_init_f(&cVar_zyAv9GYB, 0.0f);
  numBytes += cSlice_init(&cSlice_DnhdJA40, 1, -1);
  numBytes += cVar_init_f(&cVar_z8tRXTtq, 0.0f);
  numBytes += cSlice_init(&cSlice_b4xqlSgE, 1, -1);
  numBytes += cVar_init_f(&cVar_jpZMdPrq, 0.0f);
  numBytes += cSlice_init(&cSlice_I7TvgrqP, 1, -1);
  numBytes += cVar_init_f(&cVar_aAjwDCXP, 0.313f);
  numBytes += cBinop_init(&cBinop_Ja2zTTZy, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_LaweWJF4, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_n804V9HW, 0.0f);
  numBytes += cVar_init_f(&cVar_rh91WO4S, 1337.0f);
  numBytes += cVar_init_f(&cVar_gu8IuqPF, 0.3f);
  numBytes += cBinop_init(&cBinop_PAPlKye4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_c4MTDz9g, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KXUxMZXZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_j3oAlhbU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wfrQflPR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_pjCnWrxZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NLwL4bq5, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_fCRTwPVp, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_hwNcd1Py, 0.0f);
  numBytes += cVar_init_f(&cVar_K7TskBoY, 1337.0f);
  numBytes += cVar_init_f(&cVar_XglvraEc, 0.313f);
  numBytes += cBinop_init(&cBinop_LVJzLVhr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bWrFTUfH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_npB8VbUi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GSnG9B3i, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_I9jln8c6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DGwjxIxf, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_QyZFyKSz, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_AJ6lkvyY, 0.0f);
  numBytes += cVar_init_f(&cVar_Zwf5bN8t, 1037.0f);
  numBytes += cVar_init_f(&cVar_0xn1eWj3, 0.4f);
  numBytes += cBinop_init(&cBinop_OIvVBUs7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uIDoQi0n, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Cq6mkKGU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FtelRgR6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xEYOt3et, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1Uc1FFHy, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_VLcMTiW7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CNRXIg57, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jDtDyJsp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cgQt33QM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_m8Dpuu7I, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BBgKLty9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oY1ADyOm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Oh3AXYxM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xzxEVkmt, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_23r5D3D6, 5705.6f);
  numBytes += cVar_init_f(&cVar_thaJpZ9A, 313.3f);
  numBytes += cBinop_init(&cBinop_LUJ22E11, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_RDvrZnyd, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_g4hQNDck, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_EQ::~Heavy_WSTD_EQ() {
  // nothing to free
}

HvTable *Heavy_WSTD_EQ::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_EQ::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nROUAtnE_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Baj6m5D3_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JWWltq2i_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P1nWethQ_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rJnSh8ty_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5pxaqpCJ_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bwWe1eKc_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_L9ie4pW0_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Pk3J3FWr_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YMLR4bWg_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1uukJvLb_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LxNaQQ2y_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Aak0DAR3_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JN0Axs3W_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rkNdC3v4_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_em2JHF1x_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_v3TC0d3S_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XmCd1KcI_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pVi1GzjM_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TVOfHe3B_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PWdt1QPl_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qRvpNtna_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RUnorDEv_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NDMxZ6Sp_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nNv9uUlk_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bLD4uKY7_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Utg5zv0R_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rRXg3prH_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rY1f2ZNF_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nZKyueI5_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qd7A8AIa_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iLmjMNt4_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GKCcu1id_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_EQ::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_EQ::cVar_1VUSKlld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KxuitFKM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_oEKqNexC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GnN0KIsl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_he2YFzvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xyr7VFkr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_xRa6PlSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jWPdz7dC_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o3jwWUhc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a7C8LwRV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4MOjHjQh_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_Szlj4jPU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_lYe1d4e1, 0, m, &cSlice_lYe1d4e1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hSUh0bUn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_lYe1d4e1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UEn70r9k_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UEn70r9k_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_vrO2Tzyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UEn70r9k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_UEn70r9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bwWe1eKc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_GgWykoIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_tbJHvpWX_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_StZgrh1c, 0, m, &cIf_StZgrh1c_sendMessage);
}

void Heavy_WSTD_EQ::cIf_StZgrh1c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_80mdMmcN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_PZxGWwBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_FtsxlPtx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_g8ZHCCOE_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_0amoZUz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_20TSnc5w, HV_BINOP_POW, 0, m, &cBinop_20TSnc5w_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_20TSnc5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bLKO5pCY, 0, m, &cIf_bLKO5pCY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_j7K0UB4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_5QHOCdRu_sendMessage);
}

void Heavy_WSTD_EQ::cCast_o9Si5O2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_BAsDy2An_sendMessage);
}

void Heavy_WSTD_EQ::cCast_yShEItz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PZxGWwBQ, 0, m, &cIf_PZxGWwBQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BAsDy2An_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PZxGWwBQ, 1, m, &cIf_PZxGWwBQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_g8ZHCCOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_j7K0UB4r_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_FtsxlPtx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_bLKO5pCY, 0, m, &cIf_bLKO5pCY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5QHOCdRu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_20TSnc5w, HV_BINOP_POW, 1, m, &cBinop_20TSnc5w_sendMessage);
  cMsg_0amoZUz7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_bLKO5pCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_h1dMVlpZ, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_tbJHvpWX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_StZgrh1c, 1, m, &cIf_StZgrh1c_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_80mdMmcN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xD08bjeV, HV_BINOP_GREATER_THAN, 1, m, &cBinop_xD08bjeV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PcOJcRO3, HV_BINOP_EQ, 1, m, &cBinop_PcOJcRO3_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_yQrLI3wZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qbC3jQkQ, HV_BINOP_ADD, 0, m, &cBinop_qbC3jQkQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qbC3jQkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_o9Si5O2S_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yShEItz8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xD08bjeV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bLKO5pCY, 1, m, &cIf_bLKO5pCY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PcOJcRO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qooOlxVD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_qooOlxVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_h1dMVlpZ, m);
}

void Heavy_WSTD_EQ::cCast_iMU0fbFB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qbC3jQkQ, HV_BINOP_ADD, 1, m, &cBinop_qbC3jQkQ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xD08bjeV, HV_BINOP_GREATER_THAN, 0, m, &cBinop_xD08bjeV_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PcOJcRO3, HV_BINOP_EQ, 0, m, &cBinop_PcOJcRO3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_sjpUM3V5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GgWykoIc, 0, m, &cVar_GgWykoIc_sendMessage);
}

void Heavy_WSTD_EQ::cCast_d3eFNzCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yQrLI3wZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_peiNUwJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_diHv8cp3_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_7h5Ez9Zc, 0, m, &cIf_7h5Ez9Zc_sendMessage);
}

void Heavy_WSTD_EQ::cIf_7h5Ez9Zc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_pvRHJen7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_1URkCSDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_mSas6CBW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_JYBTs37w_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_nhLxCgpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_glCTGpc3, HV_BINOP_POW, 0, m, &cBinop_glCTGpc3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_glCTGpc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mqIKI0QJ, 0, m, &cIf_mqIKI0QJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Lzds9ulQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_dz1YnVkx_sendMessage);
}

void Heavy_WSTD_EQ::cCast_m4Tjz9Lg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1URkCSDm, 0, m, &cIf_1URkCSDm_sendMessage);
}

void Heavy_WSTD_EQ::cCast_R4PtCLNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_f1agnqky_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_f1agnqky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1URkCSDm, 1, m, &cIf_1URkCSDm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JYBTs37w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Lzds9ulQ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_mSas6CBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_mqIKI0QJ, 0, m, &cIf_mqIKI0QJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dz1YnVkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_glCTGpc3, HV_BINOP_POW, 1, m, &cBinop_glCTGpc3_sendMessage);
  cMsg_nhLxCgpq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_mqIKI0QJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qC50caMz_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_efxz3pb2_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_DojUuHWb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_diHv8cp3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7h5Ez9Zc, 1, m, &cIf_7h5Ez9Zc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pvRHJen7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6hPnfII1, HV_BINOP_GREATER_THAN, 1, m, &cBinop_6hPnfII1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0aOGmdqi, HV_BINOP_EQ, 1, m, &cBinop_0aOGmdqi_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Fy8ZQuBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ECw4NIWb, HV_BINOP_ADD, 0, m, &cBinop_ECw4NIWb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ECw4NIWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_R4PtCLNh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m4Tjz9Lg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6hPnfII1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mqIKI0QJ, 1, m, &cIf_mqIKI0QJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0aOGmdqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h5BulwXt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_h5BulwXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qC50caMz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_efxz3pb2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_DojUuHWb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qAtUiFSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fy8ZQuBs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_Fu8dj7tN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ECw4NIWb, HV_BINOP_ADD, 1, m, &cBinop_ECw4NIWb_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6hPnfII1, HV_BINOP_GREATER_THAN, 0, m, &cBinop_6hPnfII1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0aOGmdqi, HV_BINOP_EQ, 0, m, &cBinop_0aOGmdqi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_goh3u3ug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_peiNUwJw, 0, m, &cVar_peiNUwJw_sendMessage);
}

void Heavy_WSTD_EQ::cVar_H9nCzFB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uBD4GQnU_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_POuYB8Qg, 0, m, &cIf_POuYB8Qg_sendMessage);
}

void Heavy_WSTD_EQ::cIf_POuYB8Qg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_tTvP54r5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_8wW2jovO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_OkxT0iF5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_JiUGYqgp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_nwWbfCDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_g8z3FevR, HV_BINOP_POW, 0, m, &cBinop_g8z3FevR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_g8z3FevR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AZXABIWk, 0, m, &cIf_AZXABIWk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_szl5DAjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_KUv3mtSk_sendMessage);
}

void Heavy_WSTD_EQ::cCast_dFI6L2I7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8wW2jovO, 0, m, &cIf_8wW2jovO_sendMessage);
}

void Heavy_WSTD_EQ::cCast_wIG2ps8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_OaGXjILt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OaGXjILt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8wW2jovO, 1, m, &cIf_8wW2jovO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JiUGYqgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_szl5DAjH_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_OkxT0iF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_AZXABIWk, 0, m, &cIf_AZXABIWk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KUv3mtSk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g8z3FevR, HV_BINOP_POW, 1, m, &cBinop_g8z3FevR_sendMessage);
  cMsg_nwWbfCDR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_AZXABIWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_7ICFxOGA, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_uBD4GQnU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_POuYB8Qg, 1, m, &cIf_POuYB8Qg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tTvP54r5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b89LsMPr, HV_BINOP_GREATER_THAN, 1, m, &cBinop_b89LsMPr_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XaPacNIw, HV_BINOP_EQ, 1, m, &cBinop_XaPacNIw_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_UMuLHNTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_tpRjZaEC, HV_BINOP_ADD, 0, m, &cBinop_tpRjZaEC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tpRjZaEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wIG2ps8W_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dFI6L2I7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_b89LsMPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AZXABIWk, 1, m, &cIf_AZXABIWk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XaPacNIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jASc43g5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_jASc43g5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_7ICFxOGA, m);
}

void Heavy_WSTD_EQ::cCast_sVM4Ki5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UMuLHNTp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_vhGVcoMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tpRjZaEC, HV_BINOP_ADD, 1, m, &cBinop_tpRjZaEC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_b89LsMPr, HV_BINOP_GREATER_THAN, 0, m, &cBinop_b89LsMPr_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XaPacNIw, HV_BINOP_EQ, 0, m, &cBinop_XaPacNIw_sendMessage);
}

void Heavy_WSTD_EQ::cCast_bdi7WnCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H9nCzFB5, 0, m, &cVar_H9nCzFB5_sendMessage);
}

void Heavy_WSTD_EQ::cIf_CpzTtGIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_24qFCSEa, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_HJ1fLuEZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gvNIRIv6, 0, m, &cSlice_gvNIRIv6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GvTawKX7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_gvNIRIv6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_MdAumJt5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_MdAumJt5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_MfUl7Qll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MdAumJt5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_MdAumJt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rJnSh8ty_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_GvTawKX7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Fo96H8Yp, 0, m, &cSlice_Fo96H8Yp_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Szlj4jPU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_Fo96H8Yp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_vpaLHiIH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_vpaLHiIH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_GYHDdMtk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vpaLHiIH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_vpaLHiIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Pk3J3FWr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_hSUh0bUn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jElulFlh, 0, m, &cSlice_jElulFlh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_1R19vqJ7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_jElulFlh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_VdpWB8RH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_VdpWB8RH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_0dKnhW9y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VdpWB8RH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_VdpWB8RH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5pxaqpCJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_1R19vqJ7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sJTOUuDp, 0, m, &cSlice_sJTOUuDp_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_sJTOUuDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rvt702dx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rvt702dx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_6q9dJT88_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rvt702dx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_rvt702dx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_L9ie4pW0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_83KLSFmj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oIDNwRB4, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_tPX2mtZ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_g2eww61p, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_wuZrg55D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yxaBnASD, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_aX5IuQYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sv7djy5m, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_yAU81QU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OsEGMFGH, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_cTlgz51N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_B9FJDEUf_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_B9FJDEUf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NGxRG1gn, HV_BINOP_DIVIDE, 1, m, &cBinop_NGxRG1gn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CqLRrWG6_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_sVuwbFnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_u88MyiRA_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_WGtJHFY1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_sVuwbFnl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_u88MyiRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NGxRG1gn, HV_BINOP_DIVIDE, 0, m, &cBinop_NGxRG1gn_sendMessage);
}

void Heavy_WSTD_EQ::cCast_CqLRrWG6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WGtJHFY1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_NGxRG1gn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wy6iGeNh, HV_BINOP_MULTIPLY, 1, m, &cBinop_wy6iGeNh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wy6iGeNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hlmfMIK0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9G8Klvf7_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_LJeNzuJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Jl8dx8CD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_NjeHFPYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_z20kMTjb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_uOZntB6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_3xVD9B8T_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3xVD9B8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wy6iGeNh, HV_BINOP_MULTIPLY, 0, m, &cBinop_wy6iGeNh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EstoPiUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_JT7Ns62f_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JT7Ns62f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QtlNl3lR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_qodGIkQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wII1QFwK, 1, m, &cVar_wII1QFwK_sendMessage);
}

void Heavy_WSTD_EQ::cVar_wII1QFwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V9pk4E6Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_PiEHNWji_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yLYUBNcd, HV_BINOP_MULTIPLY, 1, m, &cBinop_yLYUBNcd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AVs5iu0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_PiEHNWji_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bJzdaYVk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_WytLsADh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WytLsADh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KKgN74Ce, HV_BINOP_MULTIPLY, 1, m, &cBinop_KKgN74Ce_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_069Yrj2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1JUK97cM, HV_BINOP_MULTIPLY, 1, m, &cBinop_1JUK97cM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3YrTCjYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_069Yrj2C_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ISjdXJDV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1iPKdU4Y, HV_BINOP_MULTIPLY, 1, m, &cBinop_1iPKdU4Y_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_XBpKy44d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_n8kbIup6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_n8kbIup6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Iv989HUL, HV_BINOP_MULTIPLY, 1, m, &cBinop_Iv989HUL_sendMessage);
}

void Heavy_WSTD_EQ::cVar_VjdWjhmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_snWo0s07_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_uOZntB6h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r0ejlWSJ_sendMessage);
}

void Heavy_WSTD_EQ::cVar_HCTvKMO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_EstoPiUt_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9G8Klvf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_NjeHFPYt_sendMessage);
}

void Heavy_WSTD_EQ::cCast_hlmfMIK0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_LJeNzuJT_sendMessage);
}

void Heavy_WSTD_EQ::cSend_Jl8dx8CD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LxNaQQ2y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_z20kMTjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1uukJvLb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_vs7y8Mlj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YMLR4bWg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_QtlNl3lR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_5ORgYCFe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5ORgYCFe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qXIrobaf, HV_BINOP_MULTIPLY, 1, m, &cBinop_qXIrobaf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qXIrobaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2WelfzEY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2WelfzEY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vs7y8Mlj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_V9pk4E6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_YoEjGaoK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YoEjGaoK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dnDC1LAJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fdvODSko_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_upwg7HEY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TuNTuPsE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2gIKBmhV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0xtjj0zh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yLYUBNcd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_83KLSFmj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_KKgN74Ce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tPX2mtZ6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_1JUK97cM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wuZrg55D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_1iPKdU4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aX5IuQYm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Iv989HUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yAU81QU3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_tFLrLqe4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HCTvKMO0, 1, m, &cVar_HCTvKMO0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_wO8fp7FY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VjdWjhmX, 0, m, &cVar_VjdWjhmX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2gIKBmhV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KKgN74Ce, HV_BINOP_MULTIPLY, 0, m, &cBinop_KKgN74Ce_sendMessage);
}

void Heavy_WSTD_EQ::cCast_dnDC1LAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_0xtjj0zh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yLYUBNcd, HV_BINOP_MULTIPLY, 0, m, &cBinop_yLYUBNcd_sendMessage);
}

void Heavy_WSTD_EQ::cCast_fdvODSko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Iv989HUL, HV_BINOP_MULTIPLY, 0, m, &cBinop_Iv989HUL_sendMessage);
}

void Heavy_WSTD_EQ::cCast_upwg7HEY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1iPKdU4Y, HV_BINOP_MULTIPLY, 0, m, &cBinop_1iPKdU4Y_sendMessage);
}

void Heavy_WSTD_EQ::cCast_TuNTuPsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1JUK97cM, HV_BINOP_MULTIPLY, 0, m, &cBinop_1JUK97cM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_r0ejlWSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wII1QFwK, 0, m, &cVar_wII1QFwK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_snWo0s07_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HCTvKMO0, 0, m, &cVar_HCTvKMO0_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_crGN1c8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hPlV1gZO, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_rzPrlzj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lAjyaGno, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_dHyx4Nvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7ySbxA0C, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_39EMJBsd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nMKTl4O3, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_MRNtKtYr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rrJ6RlRG_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_rrJ6RlRG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WefrlnoH, HV_BINOP_DIVIDE, 1, m, &cBinop_WefrlnoH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gFqb6Br8_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_AILYnYDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_TzYkresa_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Ht5zTN9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_AILYnYDT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TzYkresa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WefrlnoH, HV_BINOP_DIVIDE, 0, m, &cBinop_WefrlnoH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gFqb6Br8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ht5zTN9l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_WefrlnoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D7dTuXiz, HV_BINOP_MULTIPLY, 1, m, &cBinop_D7dTuXiz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_D7dTuXiz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ej6nYk82_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FMsrVorE_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_MhTc0ZOO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eJXADy7q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_GlkPkoC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bjgxP3Ny_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Ty9Y2oJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_FlX90UVp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FlX90UVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D7dTuXiz, HV_BINOP_MULTIPLY, 0, m, &cBinop_D7dTuXiz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TZTL71Di_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_vlJh0pe6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vlJh0pe6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bqY0GiOk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_1LSazRc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OeQHLct9, HV_BINOP_MULTIPLY, 1, m, &cBinop_OeQHLct9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tC1gT2uH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S4TPiMmV, 1, m, &cVar_S4TPiMmV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4jtuOfKa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Sg3RgKYT, HV_BINOP_MULTIPLY, 1, m, &cBinop_Sg3RgKYT_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_u77ZdL1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MeqsTeH0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MeqsTeH0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oGR7EQsT, HV_BINOP_MULTIPLY, 1, m, &cBinop_oGR7EQsT_sendMessage);
}

void Heavy_WSTD_EQ::cVar_S4TPiMmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o3mCLZ8S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_fdRjYPc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T2X9wTZt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Ty9Y2oJX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eBDzPZL7_sendMessage);
}

void Heavy_WSTD_EQ::cVar_KMr2c1JS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_TZTL71Di_sendMessage);
}

void Heavy_WSTD_EQ::cCast_FMsrVorE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_GlkPkoC1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ej6nYk82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_MhTc0ZOO_sendMessage);
}

void Heavy_WSTD_EQ::cSend_eJXADy7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rkNdC3v4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_bjgxP3Ny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JN0Axs3W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_EtQqzU7k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Aak0DAR3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_bqY0GiOk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_F3stp9c3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_F3stp9c3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QNLcoVnP, HV_BINOP_MULTIPLY, 1, m, &cBinop_QNLcoVnP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QNLcoVnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SsI4pf4q_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SsI4pf4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EtQqzU7k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_o3mCLZ8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZkEIQ0UG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZkEIQ0UG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ytj3jEJe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DOb19L87_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hdaAoxAS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6vWvqstr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_84FnrTph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_crGN1c8c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_OeQHLct9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rzPrlzj3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Sg3RgKYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dHyx4Nvh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_oGR7EQsT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_39EMJBsd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_59jhKYFa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KMr2c1JS, 1, m, &cVar_KMr2c1JS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_1l8srMHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fdRjYPc3, 0, m, &cVar_fdRjYPc3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_eBDzPZL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_S4TPiMmV, 0, m, &cVar_S4TPiMmV_sendMessage);
}

void Heavy_WSTD_EQ::cCast_T2X9wTZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KMr2c1JS, 0, m, &cVar_KMr2c1JS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ytj3jEJe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oGR7EQsT, HV_BINOP_MULTIPLY, 0, m, &cBinop_oGR7EQsT_sendMessage);
}

void Heavy_WSTD_EQ::cCast_DOb19L87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Sg3RgKYT, HV_BINOP_MULTIPLY, 0, m, &cBinop_Sg3RgKYT_sendMessage);
}

void Heavy_WSTD_EQ::cCast_hdaAoxAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OeQHLct9, HV_BINOP_MULTIPLY, 0, m, &cBinop_OeQHLct9_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6vWvqstr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_84FnrTph, HV_BINOP_MULTIPLY, 0, m, &cBinop_84FnrTph_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_zJrcFzRl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7VKn1ntj, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_hHWs8Byn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FKtLizkA, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_sFLpTt5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yJrVmjc1, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_bqcvvzS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tPZM1fPE, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Dqw9R0kp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aPiqalVm, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_hiHkKwFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Z5Ub4iI6_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_Z5Ub4iI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a29Wh1vc, HV_BINOP_DIVIDE, 1, m, &cBinop_a29Wh1vc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7qiigzyT_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_vwnIR9Hx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_fgd0pSDp_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Q59K7TD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_vwnIR9Hx_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fgd0pSDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a29Wh1vc, HV_BINOP_DIVIDE, 0, m, &cBinop_a29Wh1vc_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7qiigzyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q59K7TD3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_a29Wh1vc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CAPgf3BQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_CAPgf3BQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CAPgf3BQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q4gppIhT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mvdLyvZ0_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_u3b8EOVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iVIO4OWj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_pKpga3lb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_y1hcT3Ne_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_C8ysqepD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_9ujvh1gJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9ujvh1gJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CAPgf3BQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_CAPgf3BQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hsvOpHnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_VEBNpaAS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VEBNpaAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kVEgRKh7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_VqATldA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZBIuIgDz, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZBIuIgDz_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_sAjd6vjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_6RBoNdWw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6RBoNdWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_VqATldA6_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_8yMCrfbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3CvMjGFt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3CvMjGFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5GJc0qpD, HV_BINOP_MULTIPLY, 1, m, &cBinop_5GJc0qpD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dl7fDLor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AuRMijMd, HV_BINOP_MULTIPLY, 1, m, &cBinop_AuRMijMd_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_W7LJKBBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rsNA1XPG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rsNA1XPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_dl7fDLor_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SW8oh5Ti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_65QsiDbn, 1, m, &cVar_65QsiDbn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_n0Xv6n1M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7o7GE8IU, HV_BINOP_MULTIPLY, 1, m, &cBinop_7o7GE8IU_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_A9vnxjiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_EEQntRUw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EEQntRUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3EkL3c8Q, HV_BINOP_MULTIPLY, 1, m, &cBinop_3EkL3c8Q_sendMessage);
}

void Heavy_WSTD_EQ::cVar_65QsiDbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pRWhNIPV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_tzQ9uwCR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bbbhlF1C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_C8ysqepD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_josPDXg6_sendMessage);
}

void Heavy_WSTD_EQ::cVar_M1LwUZBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_hsvOpHnr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Q4gppIhT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_u3b8EOVZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_mvdLyvZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_pKpga3lb_sendMessage);
}

void Heavy_WSTD_EQ::cSend_iVIO4OWj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XmCd1KcI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_y1hcT3Ne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_v3TC0d3S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_d8AEJKTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_em2JHF1x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_kVEgRKh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8jMuCKxt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8jMuCKxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sq9cXgNz, HV_BINOP_MULTIPLY, 1, m, &cBinop_sq9cXgNz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sq9cXgNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Ya3Q2XL2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ya3Q2XL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_d8AEJKTY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_pRWhNIPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_kVrht0w0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kVrht0w0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CacHgGhI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_74Zjllqr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0WXl0qmC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KmGvOHZ3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NyiEUH1E_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xpPfuXWY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZBIuIgDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zJrcFzRl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_5GJc0qpD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hHWs8Byn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_AuRMijMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sFLpTt5L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_7o7GE8IU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bqcvvzS8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_3EkL3c8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Dqw9R0kp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_OLfFVuI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M1LwUZBm, 1, m, &cVar_M1LwUZBm_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ctaRPBKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tzQ9uwCR, 0, m, &cVar_tzQ9uwCR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_0WXl0qmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7o7GE8IU, HV_BINOP_MULTIPLY, 0, m, &cBinop_7o7GE8IU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_KmGvOHZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AuRMijMd, HV_BINOP_MULTIPLY, 0, m, &cBinop_AuRMijMd_sendMessage);
}

void Heavy_WSTD_EQ::cCast_74Zjllqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3EkL3c8Q, HV_BINOP_MULTIPLY, 0, m, &cBinop_3EkL3c8Q_sendMessage);
}

void Heavy_WSTD_EQ::cCast_xpPfuXWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZBIuIgDz, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZBIuIgDz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_CacHgGhI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_NyiEUH1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5GJc0qpD, HV_BINOP_MULTIPLY, 0, m, &cBinop_5GJc0qpD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_josPDXg6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_65QsiDbn, 0, m, &cVar_65QsiDbn_sendMessage);
}

void Heavy_WSTD_EQ::cCast_bbbhlF1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_M1LwUZBm, 0, m, &cVar_M1LwUZBm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qC50caMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CpzTtGIG, 1, m, &cIf_CpzTtGIG_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_NiJzfIC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_24qFCSEa, m);
}

void Heavy_WSTD_EQ::cBinop_efxz3pb2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NiJzfIC3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_DojUuHWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CpzTtGIG, 0, m, &cIf_CpzTtGIG_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_c4ZrQBXa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_OTCFyzze, 0, m, &cSlice_OTCFyzze_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PhXSgPXq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_OTCFyzze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qlE7pcPd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qlE7pcPd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_0ZB4d1FS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qlE7pcPd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_qlE7pcPd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PWdt1QPl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_KYHLDl6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_zCEb89Ms_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_sArZq3z3, 0, m, &cIf_sArZq3z3_sendMessage);
}

void Heavy_WSTD_EQ::cIf_sArZq3z3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_VL4cX8Ch_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_pchDWC0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_grMTm2T3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Q2HdK7xW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_Yqb2hzkc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MxtWx4iX, HV_BINOP_POW, 0, m, &cBinop_MxtWx4iX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MxtWx4iX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5k4rX5kZ, 0, m, &cIf_5k4rX5kZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sFeW4mPL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_evynoLNx_sendMessage);
}

void Heavy_WSTD_EQ::cCast_JlcL2hXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pchDWC0n, 0, m, &cIf_pchDWC0n_sendMessage);
}

void Heavy_WSTD_EQ::cCast_32CD65ZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xo2ivqpJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xo2ivqpJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pchDWC0n, 1, m, &cIf_pchDWC0n_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Q2HdK7xW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_sFeW4mPL_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_grMTm2T3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_5k4rX5kZ, 0, m, &cIf_5k4rX5kZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_evynoLNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MxtWx4iX, HV_BINOP_POW, 1, m, &cBinop_MxtWx4iX_sendMessage);
  cMsg_Yqb2hzkc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_5k4rX5kZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_VLcMTiW7, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_zCEb89Ms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sArZq3z3, 1, m, &cIf_sArZq3z3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VL4cX8Ch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7X8Qp76H, HV_BINOP_GREATER_THAN, 1, m, &cBinop_7X8Qp76H_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PCo8nGDd, HV_BINOP_EQ, 1, m, &cBinop_PCo8nGDd_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_TopAltZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_NFs7ZE7m, HV_BINOP_ADD, 0, m, &cBinop_NFs7ZE7m_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NFs7ZE7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_32CD65ZR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JlcL2hXF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7X8Qp76H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5k4rX5kZ, 1, m, &cIf_5k4rX5kZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PCo8nGDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nMzXDwVo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_nMzXDwVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_VLcMTiW7, m);
}

void Heavy_WSTD_EQ::cCast_ab3RtfLn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NFs7ZE7m, HV_BINOP_ADD, 1, m, &cBinop_NFs7ZE7m_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7X8Qp76H, HV_BINOP_GREATER_THAN, 0, m, &cBinop_7X8Qp76H_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PCo8nGDd, HV_BINOP_EQ, 0, m, &cBinop_PCo8nGDd_sendMessage);
}

void Heavy_WSTD_EQ::cCast_z4ZXUuZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KYHLDl6Q, 0, m, &cVar_KYHLDl6Q_sendMessage);
}

void Heavy_WSTD_EQ::cCast_F0W1a6HN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TopAltZG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_jwgm1GY8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_CXni3fk0_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_9pPRJh8F, 0, m, &cIf_9pPRJh8F_sendMessage);
}

void Heavy_WSTD_EQ::cIf_9pPRJh8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_6C0j2mQO_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_OOh7vfXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Rk1fGZys_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_OtPovGQb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_s1sI4hST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4p1iFxgk, HV_BINOP_POW, 0, m, &cBinop_4p1iFxgk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4p1iFxgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WJQnBdqf, 0, m, &cIf_WJQnBdqf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3QCiOEvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_V5wfxTfw_sendMessage);
}

void Heavy_WSTD_EQ::cCast_FWUufxqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nDZMxG8o_sendMessage);
}

void Heavy_WSTD_EQ::cCast_csENvkki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OOh7vfXP, 0, m, &cIf_OOh7vfXP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nDZMxG8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OOh7vfXP, 1, m, &cIf_OOh7vfXP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OtPovGQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_3QCiOEvw_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Rk1fGZys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_WJQnBdqf, 0, m, &cIf_WJQnBdqf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_V5wfxTfw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4p1iFxgk, HV_BINOP_POW, 1, m, &cBinop_4p1iFxgk_sendMessage);
  cMsg_s1sI4hST_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_WJQnBdqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_lrZJdMlf_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1eAzubUA_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_6E2htVTg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_CXni3fk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9pPRJh8F, 1, m, &cIf_9pPRJh8F_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6C0j2mQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_S5acli40, HV_BINOP_GREATER_THAN, 1, m, &cBinop_S5acli40_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_H4TXB2Go, HV_BINOP_EQ, 1, m, &cBinop_H4TXB2Go_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_8uvRPBGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_k8S57yox, HV_BINOP_ADD, 0, m, &cBinop_k8S57yox_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_k8S57yox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FWUufxqM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_csENvkki_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_S5acli40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WJQnBdqf, 1, m, &cIf_WJQnBdqf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_H4TXB2Go_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0HEZ86i4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_0HEZ86i4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_lrZJdMlf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1eAzubUA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_6E2htVTg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_IkJOOxIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8uvRPBGM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_zGPCzoIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k8S57yox, HV_BINOP_ADD, 1, m, &cBinop_k8S57yox_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_S5acli40, HV_BINOP_GREATER_THAN, 0, m, &cBinop_S5acli40_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_H4TXB2Go, HV_BINOP_EQ, 0, m, &cBinop_H4TXB2Go_sendMessage);
}

void Heavy_WSTD_EQ::cCast_eRvtyZ0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jwgm1GY8, 0, m, &cVar_jwgm1GY8_sendMessage);
}

void Heavy_WSTD_EQ::cVar_OsHshlk3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_cutgKjQh_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ECVFvbtQ, 0, m, &cIf_ECVFvbtQ_sendMessage);
}

void Heavy_WSTD_EQ::cIf_ECVFvbtQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_usxiwDMf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_lQRs23PQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_PlfIMdrt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_DvkcJMNT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_ZhYlifBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_QwxcfBo3, HV_BINOP_POW, 0, m, &cBinop_QwxcfBo3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QwxcfBo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_36sNSBSu, 0, m, &cIf_36sNSBSu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MOLSaVuI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_XvEYczBO_sendMessage);
}

void Heavy_WSTD_EQ::cCast_0OEC7f2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lQRs23PQ, 0, m, &cIf_lQRs23PQ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qeAifqPd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_kDtJgC2w_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kDtJgC2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lQRs23PQ, 1, m, &cIf_lQRs23PQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DvkcJMNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_MOLSaVuI_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_PlfIMdrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_36sNSBSu, 0, m, &cIf_36sNSBSu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XvEYczBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QwxcfBo3, HV_BINOP_POW, 1, m, &cBinop_QwxcfBo3_sendMessage);
  cMsg_ZhYlifBC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_36sNSBSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_jDtDyJsp, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_cutgKjQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ECVFvbtQ, 1, m, &cIf_ECVFvbtQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_usxiwDMf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sH5C9cxr, HV_BINOP_GREATER_THAN, 1, m, &cBinop_sH5C9cxr_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_v2lVd3eS, HV_BINOP_EQ, 1, m, &cBinop_v2lVd3eS_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Xl4YRpYu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rQOcc2rm, HV_BINOP_ADD, 0, m, &cBinop_rQOcc2rm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rQOcc2rm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qeAifqPd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0OEC7f2J_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sH5C9cxr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_36sNSBSu, 1, m, &cIf_36sNSBSu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_v2lVd3eS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wdnSwYv0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_wdnSwYv0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_jDtDyJsp, m);
}

void Heavy_WSTD_EQ::cCast_JL3kXSCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OsHshlk3, 0, m, &cVar_OsHshlk3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LFJzqJx8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xl4YRpYu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_aiLvbjxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rQOcc2rm, HV_BINOP_ADD, 1, m, &cBinop_rQOcc2rm_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sH5C9cxr, HV_BINOP_GREATER_THAN, 0, m, &cBinop_sH5C9cxr_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_v2lVd3eS, HV_BINOP_EQ, 0, m, &cBinop_v2lVd3eS_sendMessage);
}

void Heavy_WSTD_EQ::cIf_xC9e56LR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_CNRXIg57, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_Gjwf1HWa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6nANz90T, 0, m, &cSlice_6nANz90T_sendMessage);
      break;
    }
    default: {
      cSwitchcase_RkV4avAK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_6nANz90T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_M0dLdLxf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_M0dLdLxf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_zyAv9GYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_M0dLdLxf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_M0dLdLxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pVi1GzjM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_RkV4avAK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DnhdJA40, 0, m, &cSlice_DnhdJA40_sendMessage);
      break;
    }
    default: {
      cSwitchcase_c4ZrQBXa_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_DnhdJA40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gcNB26o0_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gcNB26o0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_z8tRXTtq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gcNB26o0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_gcNB26o0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RUnorDEv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_PhXSgPXq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_b4xqlSgE, 0, m, &cSlice_b4xqlSgE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MmGtgXBJ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_b4xqlSgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_n3X8VaMZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_n3X8VaMZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_jpZMdPrq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_n3X8VaMZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_n3X8VaMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TVOfHe3B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_MmGtgXBJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_I7TvgrqP, 0, m, &cSlice_I7TvgrqP_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_I7TvgrqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pZm9KXx7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pZm9KXx7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_aAjwDCXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pZm9KXx7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_pZm9KXx7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qRvpNtna_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_p8fn6Jg4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pglqpfwH, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_GVdfOCiV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Jff4iP70, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_TthioetN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rCIlL3GO, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_52UGStkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Bp2NubGC, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_uv2mbXfj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9ffIT4ej, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_zuGRraS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QLogKkFF_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_QLogKkFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ja2zTTZy, HV_BINOP_DIVIDE, 1, m, &cBinop_Ja2zTTZy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ReClTFjc_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_G79cySih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_eJwYQ3Wl_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_2ehpCojp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_G79cySih_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_eJwYQ3Wl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ja2zTTZy, HV_BINOP_DIVIDE, 0, m, &cBinop_Ja2zTTZy_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ReClTFjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2ehpCojp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Ja2zTTZy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LaweWJF4, HV_BINOP_MULTIPLY, 1, m, &cBinop_LaweWJF4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LaweWJF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OcuzvDbw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KuTqhWuN_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_HDBKiY2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_n90ekfJP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_tEp3WmPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hlKxbH4b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_SymJzGcr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_6Epk2tzH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6Epk2tzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LaweWJF4, HV_BINOP_MULTIPLY, 0, m, &cBinop_LaweWJF4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lfAgfmlF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_uO0kC3ea_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uO0kC3ea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7r4v6JWe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_BUQscI0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_n804V9HW, 1, m, &cVar_n804V9HW_sendMessage);
}

void Heavy_WSTD_EQ::cVar_n804V9HW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Amt1midJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_H6Necpo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c4MTDz9g, HV_BINOP_MULTIPLY, 1, m, &cBinop_c4MTDz9g_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NyRekMvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_H6Necpo7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_txgcf6N7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_T8BfGqXh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_T8BfGqXh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KXUxMZXZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_KXUxMZXZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_owJmt3eT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j3oAlhbU, HV_BINOP_MULTIPLY, 1, m, &cBinop_j3oAlhbU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qwEnHDUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_owJmt3eT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BTNQWwHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wfrQflPR, HV_BINOP_MULTIPLY, 1, m, &cBinop_wfrQflPR_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_vPYVQWt8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_0YUrub6P_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0YUrub6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pjCnWrxZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_pjCnWrxZ_sendMessage);
}

void Heavy_WSTD_EQ::cVar_rh91WO4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IBcXc91h_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_SymJzGcr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1TrHnZ76_sendMessage);
}

void Heavy_WSTD_EQ::cVar_gu8IuqPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_lfAgfmlF_sendMessage);
}

void Heavy_WSTD_EQ::cCast_KuTqhWuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_tEp3WmPO_sendMessage);
}

void Heavy_WSTD_EQ::cCast_OcuzvDbw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_HDBKiY2q_sendMessage);
}

void Heavy_WSTD_EQ::cSend_n90ekfJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bLD4uKY7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_hlKxbH4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nNv9uUlk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_hYGRfQrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NDMxZ6Sp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_7r4v6JWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_RzgeEJr3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RzgeEJr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PAPlKye4, HV_BINOP_MULTIPLY, 1, m, &cBinop_PAPlKye4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PAPlKye4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_1w6Dkiqk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1w6Dkiqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hYGRfQrp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_Amt1midJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_cMsuuH6Z_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cMsuuH6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_97XWIguG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t4QycUdF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uQTkFm2r_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N3ScA7YB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jNc61ule_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ifwUBCKM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_c4MTDz9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p8fn6Jg4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_KXUxMZXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GVdfOCiV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_j3oAlhbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TthioetN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_wfrQflPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_52UGStkC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_pjCnWrxZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uv2mbXfj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_cbFsgCmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rh91WO4S, 0, m, &cVar_rh91WO4S_sendMessage);
}

void Heavy_WSTD_EQ::cCast_rU69UVlq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gu8IuqPF, 1, m, &cVar_gu8IuqPF_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ifwUBCKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c4MTDz9g, HV_BINOP_MULTIPLY, 0, m, &cBinop_c4MTDz9g_sendMessage);
}

void Heavy_WSTD_EQ::cCast_N3ScA7YB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j3oAlhbU, HV_BINOP_MULTIPLY, 0, m, &cBinop_j3oAlhbU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_uQTkFm2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wfrQflPR, HV_BINOP_MULTIPLY, 0, m, &cBinop_wfrQflPR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_t4QycUdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pjCnWrxZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_pjCnWrxZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jNc61ule_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KXUxMZXZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_KXUxMZXZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_97XWIguG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_1TrHnZ76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_n804V9HW, 0, m, &cVar_n804V9HW_sendMessage);
}

void Heavy_WSTD_EQ::cCast_IBcXc91h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gu8IuqPF, 0, m, &cVar_gu8IuqPF_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_X6FIX6Vh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OHWkXJ1m, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_hTUMXUpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XaA7LH24, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_U52DvwZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_m5hq0WPa, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_LgX0mjdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gkennT1q, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_2Gq3gzAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FqM9vpxl_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_FqM9vpxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NLwL4bq5, HV_BINOP_DIVIDE, 1, m, &cBinop_NLwL4bq5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LTUETP30_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_QD4GIjNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_d2WuTyvI_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_FvwdWonF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_QD4GIjNe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_d2WuTyvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NLwL4bq5, HV_BINOP_DIVIDE, 0, m, &cBinop_NLwL4bq5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LTUETP30_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FvwdWonF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_NLwL4bq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fCRTwPVp, HV_BINOP_MULTIPLY, 1, m, &cBinop_fCRTwPVp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fCRTwPVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v1FFkMxb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c29eDhqN_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_EyHxItxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NjR9m7sm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_lQgihfjJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iU3kdwcg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_85fFZUSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_GOBf8Dqt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GOBf8Dqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fCRTwPVp, HV_BINOP_MULTIPLY, 0, m, &cBinop_fCRTwPVp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bFVywWxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_lsDaAhKS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lsDaAhKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2H8ivPf7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_rU42iKgt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_npB8VbUi, HV_BINOP_MULTIPLY, 1, m, &cBinop_npB8VbUi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_R7HQFYcr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hwNcd1Py, 1, m, &cVar_hwNcd1Py_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_W0xJytXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GSnG9B3i, HV_BINOP_MULTIPLY, 1, m, &cBinop_GSnG9B3i_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_6pe1ZrwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_45vgPV4V_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_45vgPV4V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I9jln8c6, HV_BINOP_MULTIPLY, 1, m, &cBinop_I9jln8c6_sendMessage);
}

void Heavy_WSTD_EQ::cVar_hwNcd1Py_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OH8Z55I5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_K7TskBoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZoDF6evV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_85fFZUSi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZNQ9cxT6_sendMessage);
}

void Heavy_WSTD_EQ::cVar_XglvraEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_bFVywWxV_sendMessage);
}

void Heavy_WSTD_EQ::cCast_v1FFkMxb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_EyHxItxb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_c29eDhqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_lQgihfjJ_sendMessage);
}

void Heavy_WSTD_EQ::cSend_NjR9m7sm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rY1f2ZNF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_iU3kdwcg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rRXg3prH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_dS0e0ssH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Utg5zv0R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_2H8ivPf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_d0FUfCdF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_d0FUfCdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LVJzLVhr, HV_BINOP_MULTIPLY, 1, m, &cBinop_LVJzLVhr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LVJzLVhr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_F1VHmkVM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_F1VHmkVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dS0e0ssH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_OH8Z55I5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_zLPaQOVQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zLPaQOVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yGQVXvEG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_puulP1mC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8jsRi1aS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6eJ0HNdc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bWrFTUfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X6FIX6Vh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_npB8VbUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hTUMXUpE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_GSnG9B3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_U52DvwZR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_I9jln8c6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LgX0mjdn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_konAOXgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XglvraEc, 1, m, &cVar_XglvraEc_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Ukh7JRaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_K7TskBoY, 0, m, &cVar_K7TskBoY_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ZoDF6evV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XglvraEc, 0, m, &cVar_XglvraEc_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ZNQ9cxT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hwNcd1Py, 0, m, &cVar_hwNcd1Py_sendMessage);
}

void Heavy_WSTD_EQ::cCast_yGQVXvEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I9jln8c6, HV_BINOP_MULTIPLY, 0, m, &cBinop_I9jln8c6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_puulP1mC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GSnG9B3i, HV_BINOP_MULTIPLY, 0, m, &cBinop_GSnG9B3i_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6eJ0HNdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bWrFTUfH, HV_BINOP_MULTIPLY, 0, m, &cBinop_bWrFTUfH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8jsRi1aS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_npB8VbUi, HV_BINOP_MULTIPLY, 0, m, &cBinop_npB8VbUi_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_zTo3ZfoZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RRgM89lg, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Npgub575_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_INgH8amA, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_hhwUUukD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_N9bitpNe, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_vk9gYr1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pe4QlAzU, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_KT7ty421_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_n511gYbr, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_7VTzl2AN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5c07it0K_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_5c07it0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DGwjxIxf, HV_BINOP_DIVIDE, 1, m, &cBinop_DGwjxIxf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BQfFyweO_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_XZWAIqiW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Ggh7JLUW_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ye531ShB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_XZWAIqiW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ggh7JLUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DGwjxIxf, HV_BINOP_DIVIDE, 0, m, &cBinop_DGwjxIxf_sendMessage);
}

void Heavy_WSTD_EQ::cCast_BQfFyweO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ye531ShB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_DGwjxIxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QyZFyKSz, HV_BINOP_MULTIPLY, 1, m, &cBinop_QyZFyKSz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QyZFyKSz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YUTWGfTo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pFLsWNGX_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_kbAq6D3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ihyShnqs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_SZNy3gwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_d2rNIs9J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_GdN2MhgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_IpQ78yoy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IpQ78yoy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QyZFyKSz, HV_BINOP_MULTIPLY, 0, m, &cBinop_QyZFyKSz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3JQDnHZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_TrhbUsTE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TrhbUsTE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0Wnb41wp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_nQevZGvA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uIDoQi0n, HV_BINOP_MULTIPLY, 1, m, &cBinop_uIDoQi0n_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_3BUMqkiI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_UWCIyDKy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UWCIyDKy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_nQevZGvA_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_o1kq28pK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tealPr4o_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tealPr4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Cq6mkKGU, HV_BINOP_MULTIPLY, 1, m, &cBinop_Cq6mkKGU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TZwJAoUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FtelRgR6, HV_BINOP_MULTIPLY, 1, m, &cBinop_FtelRgR6_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_kjYVGW93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_UsxrsQF6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UsxrsQF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_TZwJAoUV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_04uYbpe5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AJ6lkvyY, 1, m, &cVar_AJ6lkvyY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3QWsvEy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xEYOt3et, HV_BINOP_MULTIPLY, 1, m, &cBinop_xEYOt3et_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_X3Dyt8X7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_F8vsXCwW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_F8vsXCwW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Uc1FFHy, HV_BINOP_MULTIPLY, 1, m, &cBinop_1Uc1FFHy_sendMessage);
}

void Heavy_WSTD_EQ::cVar_AJ6lkvyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rm1yhyB7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_Zwf5bN8t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mu7kE48k_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_GdN2MhgC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MtVP3CMa_sendMessage);
}

void Heavy_WSTD_EQ::cVar_0xn1eWj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_3JQDnHZe_sendMessage);
}

void Heavy_WSTD_EQ::cCast_pFLsWNGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_SZNy3gwj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_YUTWGfTo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_kbAq6D3Z_sendMessage);
}

void Heavy_WSTD_EQ::cSend_ihyShnqs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iLmjMNt4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_d2rNIs9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qd7A8AIa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_eMihhNjd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nZKyueI5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_0Wnb41wp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_pg5SRJMC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pg5SRJMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OIvVBUs7, HV_BINOP_MULTIPLY, 1, m, &cBinop_OIvVBUs7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OIvVBUs7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_BLFQJWPA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BLFQJWPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_eMihhNjd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_rm1yhyB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_iRoxLHTX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_iRoxLHTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Fh6vn4qz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jPsF7m7V_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AHzeMKbJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CRti13t7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eJNmiT5R_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nWzgt0et_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uIDoQi0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zTo3ZfoZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Cq6mkKGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Npgub575_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_FtelRgR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hhwUUukD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_xEYOt3et_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vk9gYr1E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_1Uc1FFHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KT7ty421_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_qACQsg2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Zwf5bN8t, 0, m, &cVar_Zwf5bN8t_sendMessage);
}

void Heavy_WSTD_EQ::cCast_WcJZBgot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0xn1eWj3, 1, m, &cVar_0xn1eWj3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_AHzeMKbJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xEYOt3et, HV_BINOP_MULTIPLY, 0, m, &cBinop_xEYOt3et_sendMessage);
}

void Heavy_WSTD_EQ::cCast_nWzgt0et_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uIDoQi0n, HV_BINOP_MULTIPLY, 0, m, &cBinop_uIDoQi0n_sendMessage);
}

void Heavy_WSTD_EQ::cCast_CRti13t7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FtelRgR6, HV_BINOP_MULTIPLY, 0, m, &cBinop_FtelRgR6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Fh6vn4qz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_eJNmiT5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Cq6mkKGU, HV_BINOP_MULTIPLY, 0, m, &cBinop_Cq6mkKGU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jPsF7m7V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Uc1FFHy, HV_BINOP_MULTIPLY, 0, m, &cBinop_1Uc1FFHy_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Mu7kE48k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0xn1eWj3, 0, m, &cVar_0xn1eWj3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MtVP3CMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AJ6lkvyY, 0, m, &cVar_AJ6lkvyY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lrZJdMlf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xC9e56LR, 1, m, &cIf_xC9e56LR_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_tGZijSes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_CNRXIg57, m);
}

void Heavy_WSTD_EQ::cBinop_1eAzubUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tGZijSes_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_6E2htVTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xC9e56LR, 0, m, &cIf_xC9e56LR_sendMessage);
}

void Heavy_WSTD_EQ::cVar_23r5D3D6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RDvrZnyd, HV_BINOP_DIVIDE, 0, m, &cBinop_RDvrZnyd_sendMessage);
}

void Heavy_WSTD_EQ::cVar_thaJpZ9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LUJ22E11, HV_BINOP_DIVIDE, 1, m, &cBinop_LUJ22E11_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_RDvrZnyd, HV_BINOP_DIVIDE, 1, m, &cBinop_RDvrZnyd_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_qciztkVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g4hQNDck, HV_BINOP_DIVIDE, 0, m, &cBinop_g4hQNDck_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_ST6rPDuI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g4hQNDck, HV_BINOP_DIVIDE, 1, m, &cBinop_g4hQNDck_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4MOjHjQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LUJ22E11, HV_BINOP_DIVIDE, 0, m, &cBinop_LUJ22E11_sendMessage);
}

void Heavy_WSTD_EQ::cCast_a7C8LwRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_23r5D3D6, 0, m, &cVar_23r5D3D6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_o3jwWUhc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_thaJpZ9A, 0, m, &cVar_thaJpZ9A_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LUJ22E11_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_qciztkVt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RDvrZnyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_ST6rPDuI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_g4hQNDck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_QMKB4n22_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_SkYEw6Vv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_gF0Ii98h_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vDfDHErc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_oyrsSds1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QMKB4n22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_vDfDHErc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oyrsSds1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_SkYEw6Vv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gF0Ii98h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rxJuEbvy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_KxuitFKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_HJ1fLuEZ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Gjwf1HWa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_GnN0KIsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_HJ1fLuEZ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Gjwf1HWa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_xyr7VFkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_HJ1fLuEZ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Gjwf1HWa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_jWPdz7dC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_HJ1fLuEZ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Gjwf1HWa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_rxJuEbvy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_HJ1fLuEZ_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Gjwf1HWa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_wQ86Xtz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_xRa6PlSt, 0, m, &cVar_xRa6PlSt_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_dUuYEFCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_1VUSKlld, 0, m, &cVar_1VUSKlld_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oEKqNexC, 0, m, &cVar_oEKqNexC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_he2YFzvp, 0, m, &cVar_he2YFzvp_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_nROUAtnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1VUSKlld, 0, m, &cVar_1VUSKlld_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_JWWltq2i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oEKqNexC, 0, m, &cVar_oEKqNexC_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Baj6m5D3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_he2YFzvp, 0, m, &cVar_he2YFzvp_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_bwWe1eKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fdRjYPc3, 0, m, &cVar_fdRjYPc3_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_L9ie4pW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_59jhKYFa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1l8srMHD_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_rJnSh8ty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sjpUM3V5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iMU0fbFB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d3eFNzCG_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_5pxaqpCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bdi7WnCN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vhGVcoMr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sVM4Ki5z_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Pk3J3FWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_goh3u3ug_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fu8dj7tN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qAtUiFSW_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_GKCcu1id_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cTlgz51N_sendMessage(_c, 0, m);
  cMsg_MRNtKtYr_sendMessage(_c, 0, m);
  cMsg_hiHkKwFK_sendMessage(_c, 0, m);
  cMsg_zuGRraS3_sendMessage(_c, 0, m);
  cMsg_2Gq3gzAb_sendMessage(_c, 0, m);
  cMsg_7VTzl2AN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_VjdWjhmX, 0, m, &cVar_VjdWjhmX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fdRjYPc3, 0, m, &cVar_fdRjYPc3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tzQ9uwCR, 0, m, &cVar_tzQ9uwCR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rh91WO4S, 0, m, &cVar_rh91WO4S_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_K7TskBoY, 0, m, &cVar_K7TskBoY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Zwf5bN8t, 0, m, &cVar_Zwf5bN8t_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vrO2Tzyv, 0, m, &cVar_vrO2Tzyv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GgWykoIc, 0, m, &cVar_GgWykoIc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_peiNUwJw, 0, m, &cVar_peiNUwJw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_H9nCzFB5, 0, m, &cVar_H9nCzFB5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MfUl7Qll, 0, m, &cVar_MfUl7Qll_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GYHDdMtk, 0, m, &cVar_GYHDdMtk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0dKnhW9y, 0, m, &cVar_0dKnhW9y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6q9dJT88, 0, m, &cVar_6q9dJT88_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0ZB4d1FS, 0, m, &cVar_0ZB4d1FS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KYHLDl6Q, 0, m, &cVar_KYHLDl6Q_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jwgm1GY8, 0, m, &cVar_jwgm1GY8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OsHshlk3, 0, m, &cVar_OsHshlk3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zyAv9GYB, 0, m, &cVar_zyAv9GYB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_z8tRXTtq, 0, m, &cVar_z8tRXTtq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jpZMdPrq, 0, m, &cVar_jpZMdPrq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aAjwDCXP, 0, m, &cVar_aAjwDCXP_sendMessage);
  cMsg_dUuYEFCU_sendMessage(_c, 0, m);
  cMsg_wQ86Xtz6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_LxNaQQ2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qXIrobaf, HV_BINOP_MULTIPLY, 0, m, &cBinop_qXIrobaf_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_1uukJvLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_AVs5iu0w_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_bJzdaYVk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3YrTCjYp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ISjdXJDV_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_YMLR4bWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qodGIkQ5_sendMessage);
  cMsg_XBpKy44d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_rkNdC3v4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QNLcoVnP, HV_BINOP_MULTIPLY, 0, m, &cBinop_QNLcoVnP_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_JN0Axs3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_4jtuOfKa_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Aak0DAR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_84FnrTph, HV_BINOP_MULTIPLY, 1, m, &cBinop_84FnrTph_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1LSazRc3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_tC1gT2uH_sendMessage);
  cMsg_u77ZdL1O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_XmCd1KcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sq9cXgNz, HV_BINOP_MULTIPLY, 0, m, &cBinop_sq9cXgNz_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_v3TC0d3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sAjd6vjN_sendMessage(_c, 0, m);
  cMsg_8yMCrfbT_sendMessage(_c, 0, m);
  cMsg_W7LJKBBR_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_n0Xv6n1M_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_em2JHF1x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_SW8oh5Ti_sendMessage);
  cMsg_A9vnxjiQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_PWdt1QPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_K7TskBoY, 0, m, &cVar_K7TskBoY_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_qRvpNtna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_konAOXgp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ukh7JRaZ_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_pVi1GzjM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z4ZXUuZ5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ab3RtfLn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F0W1a6HN_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_TVOfHe3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JL3kXSCn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aiLvbjxL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LFJzqJx8_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_RUnorDEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eRvtyZ0R_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zGPCzoIn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IkJOOxIc_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_bLD4uKY7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PAPlKye4, HV_BINOP_MULTIPLY, 0, m, &cBinop_PAPlKye4_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_nNv9uUlk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_NyRekMvf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_txgcf6N7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qwEnHDUL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_BTNQWwHd_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_NDMxZ6Sp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_BUQscI0g_sendMessage);
  cMsg_vPYVQWt8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_rY1f2ZNF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LVJzLVhr, HV_BINOP_MULTIPLY, 0, m, &cBinop_LVJzLVhr_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_rRXg3prH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_W0xJytXF_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Utg5zv0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bWrFTUfH, HV_BINOP_MULTIPLY, 1, m, &cBinop_bWrFTUfH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_rU42iKgt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_R7HQFYcr_sendMessage);
  cMsg_6pe1ZrwU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_iLmjMNt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OIvVBUs7, HV_BINOP_MULTIPLY, 0, m, &cBinop_OIvVBUs7_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_qd7A8AIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3BUMqkiI_sendMessage(_c, 0, m);
  cMsg_o1kq28pK_sendMessage(_c, 0, m);
  cMsg_kjYVGW93_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_3QWsvEy9_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_nZKyueI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_04uYbpe5_sendMessage);
  cMsg_X3Dyt8X7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_P1nWethQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xRa6PlSt, 0, m, &cVar_xRa6PlSt_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_EQ::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varread_f(&sVarf_cgQt33QM, VOf(Bf0));
    __hv_varread_f(&sVarf_m8Dpuu7I, VOf(Bf1));
    __hv_varread_f(&sVarf_BBgKLty9, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf0), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_oY1ADyOm, VOf(Bf0));
    __hv_varread_f(&sVarf_Oh3AXYxM, VOf(Bf1));
    __hv_varread_f(&sVarf_xzxEVkmt, VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_oIDNwRB4, VOf(Bf0));
    __hv_line_f(&sLine_g2eww61p, VOf(Bf1));
    __hv_line_f(&sLine_yxaBnASD, VOf(Bf4));
    __hv_line_f(&sLine_sv7djy5m, VOf(Bf5));
    __hv_line_f(&sLine_OsEGMFGH, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_Zlq4yOXg, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf4), VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_h1dMVlpZ, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_hPlV1gZO, VOf(Bf6));
    __hv_zero_f(VOf(Bf4));
    __hv_line_f(&sLine_lAjyaGno, VOf(Bf1));
    __hv_line_f(&sLine_7ySbxA0C, VOf(Bf0));
    __hv_line_f(&sLine_nMKTl4O3, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_OZiUGMFV, VIf(I0), VIf(Bf6), VIf(Bf4), VIf(Bf1), VIf(Bf0), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_24qFCSEa, VOf(Bf0));
    __hv_mul_f(VIf(Bf7), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_7VKn1ntj, VOf(Bf7));
    __hv_line_f(&sLine_FKtLizkA, VOf(Bf1));
    __hv_line_f(&sLine_yJrVmjc1, VOf(Bf4));
    __hv_line_f(&sLine_tPZM1fPE, VOf(Bf6));
    __hv_line_f(&sLine_aPiqalVm, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_iP9iAEsT, VIf(I0), VIf(Bf7), VIf(Bf1), VIf(Bf4), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_7ICFxOGA, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_cgQt33QM, VIf(Bf5));
    __hv_varwrite_f(&sVarf_m8Dpuu7I, VIf(Bf0));
    __hv_varwrite_f(&sVarf_BBgKLty9, VIf(Bf6));
    __hv_line_f(&sLine_pglqpfwH, VOf(Bf6));
    __hv_line_f(&sLine_Jff4iP70, VOf(Bf0));
    __hv_line_f(&sLine_rCIlL3GO, VOf(Bf5));
    __hv_line_f(&sLine_Bp2NubGC, VOf(Bf8));
    __hv_line_f(&sLine_9ffIT4ej, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_obQxFgqf, VIf(I1), VIf(Bf6), VIf(Bf0), VIf(Bf5), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_VLcMTiW7, VOf(Bf8));
    __hv_mul_f(VIf(Bf4), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_OHWkXJ1m, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_line_f(&sLine_XaA7LH24, VOf(Bf0));
    __hv_line_f(&sLine_m5hq0WPa, VOf(Bf6));
    __hv_line_f(&sLine_gkennT1q, VOf(Bf1));
    __hv_biquad_f(&sBiquad_s_sQ5GpE8k, VIf(I1), VIf(Bf4), VIf(Bf5), VIf(Bf0), VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_CNRXIg57, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_RRgM89lg, VOf(Bf1));
    __hv_line_f(&sLine_INgH8amA, VOf(Bf0));
    __hv_line_f(&sLine_N9bitpNe, VOf(Bf5));
    __hv_line_f(&sLine_pe4QlAzU, VOf(Bf4));
    __hv_line_f(&sLine_n511gYbr, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_4nWWtFCp, VIf(I1), VIf(Bf1), VIf(Bf0), VIf(Bf5), VIf(Bf4), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_jDtDyJsp, VOf(Bf4));
    __hv_mul_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_oY1ADyOm, VIf(Bf8));
    __hv_varwrite_f(&sVarf_Oh3AXYxM, VIf(Bf6));
    __hv_varwrite_f(&sVarf_xzxEVkmt, VIf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_EQ::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_EQ::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
